@@ -5,7 +5,10 @@ use 5.006;
 use strict;
 use warnings FATAL => 'all';
 
-use Mojo::Events;
+use Scalar::Util qw(weaken);
+
+use Mojolicious::Plugin::Events::Dispatcher;
+use Mojolicious::Plugin::Events::Listeners;
 
 =head1 NAME
 
@@ -13,11 +16,11 @@ Mojolicious::Plugin::Events - A plugin for dispatching and handling sync/async e
 
 =head1 VERSION
 
-Version 0.3.2
+Version 0.01
 
 =cut
 
-our $VERSION = '0.3.3';
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
@@ -45,9 +48,15 @@ Register the plugin
 sub register {
     my ($self, $app, $config) = (@_);
 
-    my $events = Mojo::Events->new(app => $app, namespaces => $config->{ namespaces });
+    my $listeners = Mojolicious::Plugin::Events::Listeners->new(app => $app, namespaces => $config->{ namespaces });
+    weaken $listeners->{ app };
 
-    $app->helper(events => sub { $events->dispatcher });
+    $app->helper(listeners => sub { $listeners });
+
+    my $events = Mojolicious::Plugin::Events::Dispatcher->new(app => $app);
+    weaken $events->{ app };
+
+    $app->helper(events => sub { $events });
 }
 
 =head1 AUTHOR
